==> thx_organization-0.0.2-py3-none-any.whl: thx/organization/models/organizations.py <==
# -*- coding: utf-8 -*-
from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _

from thx.address.models import Address, AddressCoordinate
from thx.core.models import UserModel, DateModel, StatusModel, OrderedModel, CleanModel
from .abstracts import AbstractOrganization
from .. import managers


class OrganizationAddress(
    Address, AddressCoordinate,
    CleanModel, UserModel, DateModel, StatusModel, OrderedModel
):
    organization = models.ForeignKey(
        "Organization",
        db_index=True,
        on_delete=models.PROTECT,
        related_name='addresses',
        verbose_name=_("organization"),
    )
    org_name = models.CharField(
        max_length=255,
        blank=True,
        db_index=True,
        verbose_name=_("organization name"),
    )
    note = models.TextField(
        blank=True, null=True,
        verbose_name=_("note"),
    )
    geocoding_fields = ['lat', 'lng']

    class Meta:
        verbose_name = _('organization address')
        verbose_name_plural = _('organization addresses')
        ordering = ('ordering', 'org_name',)
        permissions = (
            ("list_organizationaddress", "Can list organization address"),
            ("detail_organizationaddress", "Can detail organization address"),
            ("enable_organizationaddress", "Can enable organization address"),
            ("disable_organizationaddress", "Can disable organization address"),
        )

    def __str__(self):
        return (
            "{organization} {org_name} - {address_type} {name} {number} - {locality} ({province}) - {country}".format(
                organization=self.organization,
                org_name=self.org_name,
                address_type=self.get_address_type_display(),
                name=self.name,
                number=self.number or '',
                locality=self.locality,
                province=self.province,
                country=self.country
            )
        )

    @property
    def organization_name(self):
        return self.organization.name

    @property
    def country_name(self):
        return self.country.name


class EmailTypology(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_('code'),
    )
    name = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        max_length=255,
        unique=True,
        verbose_name=_('slug'),
    )

    class Meta:
        verbose_name = _('email typology')
        verbose_name_plural = _('email typologies')
        ordering = ('ordering', 'name',)
        permissions = (
            ("list_emailtypology", "Can list email typology"),
            ("detail_emailtypology", "Can detail email typology"),
            ("enable_emailtypology", "Can enable email typology"),
            ("disable_emailtypology", "Can disable email typology"),
        )

    def __str__(self):
        return self.name


class PhoneTypology(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_('code'),
    )
    name = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        max_length=255,
        unique=True,
        verbose_name=_('slug'),
    )

    class Meta:
        verbose_name = _('phone typology')
        verbose_name_plural = _('phone typologies')
        ordering = ('ordering', 'name',)
        permissions = (
            ("list_phonetypology", "Can list phone typology"),
            ("detail_phonetypology", "Can detail phone typology"),
            ("enable_phonetypology", "Can enable phone typology"),
            ("disable_phonetypology", "Can disable phone typology"),
        )

    def __str__(self):
        return self.name


class OrganizationType(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        max_length=50,
        verbose_name=_("code"),
    )
    category = models.CharField(
        max_length=3,
        choices=settings.ORGANIZATION_ORGANIZATIONTYPE_CATEGORY_CHOICES,
        db_index=True,
        verbose_name=_("category"),
    )
    name = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_("name"),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_("description"),
    )
    note = models.TextField(
        blank=True,
        verbose_name=_("note"),
    )

    class Meta:
        verbose_name = _('organization type')
        verbose_name_plural = _('organization types')
        ordering = ('ordering', 'name')
        permissions = (
            ("list_organizationtype", "Can list organization type"),
            ("detail_organizationtype", "Can detail organization type"),
            ("enable_organizationtype", "Can enable organization type"),
            ("disable_organizationtype", "Can disable organization type"),
        )

    def __str__(self):
        return self.name


class OrganizationForm(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        max_length=50,
        unique=True,
        verbose_name=_("code"),
    )
    name = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_("name"),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_("description"),
    )

    class Meta:
        verbose_name = _('organization form')
        verbose_name_plural = _('organization forms')
        ordering = ("ordering", "name")
        permissions = (
            ("list_organizationform", "Can list organization form"),
            ("detail_organizationform", "Can detail organization form"),
            ("disable_organizationform", "Can disable organization form"),
        )

    def __str__(self):
        return self.name


class Organization(AbstractOrganization):
    verbose_name = _('organization')
    verbose_name_plural = _('organizations')
    ordering = ('ordering', 'name',)
    permissions = (
        ("list_organization", "Can list organization"),
        ("detail_organization", "Can detail organization"),
        ("enable_organization", "Can enable organization"),
        ("disable_organization", "Can disable organization"),
    )


class OwnerOrganization(Organization):
    objects = managers.OwnerOrganizationManager()

    class Meta:
        proxy = True
        verbose_name = _('owner organization')
        verbose_name_plural = _('owner organizations')
        permissions = (
            ("list_ownerorganization", "Can list owner organization"),
            ("detail_ownerorganization", "Can detail owner organization"),
            ("enable_ownerorganization", "Can enable owner organization"),
            ("disable_ownerorganization", "Can disable owner organization"),
        )


class OrganizationEmail(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    organization = models.ForeignKey(
        "Organization",
        on_delete=models.PROTECT,
        related_name='emails',
        verbose_name=_('organization'),
    )
    typology = models.ForeignKey(
        "EmailTypology",
        on_delete=models.PROTECT,
        related_name='organization_emails',
        verbose_name=_('typology'),
    )
    email = models.EmailField(
        unique=True,
        max_length=255,
        verbose_name=_("email"),
    )
    is_primary = models.BooleanField(
        default=False,
        verbose_name=_('is primary')
    )

    class Meta:
        verbose_name = _('organization email')
        verbose_name_plural = _('organization emails')
        ordering = ('ordering', 'email',)
        permissions = (
            ("list_organizationemail", "Can list organization email"),
            ("detail_organizationemail", "Can detail organization email"),
            ("enable_organizationemail", "Can enable organization email"),
            ("disable_organizationemail", "Can disable organization email"),
        )

    def __str__(self):
        return '{}: {}'.format(self.typology, self.email)

    def save(self, *args, **kwargs):
        if self.is_primary:
            prim_emails = OrganizationEmail.objects.filter(
                organization=self.organization, is_primary=True
            )
            for email in prim_emails:
                email.is_primary = False
                email.save()
        super().save(*args, **kwargs)

    @property
    def organization_name(self):
        return self.organization.name

    @property
    def typology_name(self):
        return self.typology.name


class OrganizationPhone(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    organization = models.ForeignKey(
        Organization,
        on_delete=models.PROTECT,
        related_name='phones',
        verbose_name=_('organization'),
    )
    typology = models.ForeignKey(
        PhoneTypology,
        on_delete=models.PROTECT,
        related_name='organization_phones',
        verbose_name=_('typology'),
    )
    phone = models.CharField(
        max_length=20,
        unique=True,
        verbose_name=_("phone"),
    )
    is_primary = models.BooleanField(
        default=False,
        verbose_name=_('is primary')
    )

    class Meta:
        verbose_name = _('organization phone')
        verbose_name_plural = _('organization phones')
        permissions = (
            ("list_organizationphone", "Can list organization phone"),
            ("detail_organizationphone", "Can detail organization phone"),
            ("enable_organizationphone", "Can enable organization phone"),
            ("disable_organizationphone", "Can disable organization phone"),
        )

    def __str__(self):
        return '{}: {}'.format(self.typology, self.phone)

    def save(self, *args, **kwargs):
        if self.is_primary:
            prim_phones = OrganizationPhone.objects.filter(
                organization=self.organization, is_primary=True)
            for phone in prim_phones:
                phone.is_primary = False
                phone.save()
        super().save(*args, **kwargs)

    @property
    def organization_name(self):
        return self.organization.name

    @property
    def typology_name(self):
        return self.typology.name


class OrganizationSocialPage(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    organization = models.ForeignKey(
        Organization,
        on_delete=models.PROTECT,
        related_name='social_pages',
        verbose_name=_('organization'),
    )
    social = models.CharField(
        max_length=255,
        choices=settings.ORGANIZATION_ORGANIZATIONSOCIALPAGE_SOCIAL_DEF,
        db_index=True,
        verbose_name=_('social'),
    )
    link = models.URLField(
        unique=True,
        verbose_name=_('page link')
    )

    class Meta:
        verbose_name = _('organization social page')
        verbose_name_plural = _('organization social pages')
        ordering = ('ordering', 'link',)
        permissions = (
            ("list_organizationsocialpage", "Can list organization social page"),
            ("detail_organizationsocialpage", "Can detail organization social page"),
            ("enable_organizationsocialpage", "Can enable organization social page"),
            ("disable_organizationsocialpage", "Can disable organization social page"),
        )

    def __str__(self):
        return self.link

    @property
    def organization_name(self):
        return self.organization.name

==> thx_organization-0.1.1-py3-none-any.whl: thx/organization/models/organizations.py <==
# -*- coding: utf-8 -*-
import swapper
from django.conf import settings
from django.db import models
from django.utils.translation import gettext_lazy as _
from thx.address.models import Address, AddressCoordinate
from thx.core.models import CleanModel, DateModel, OrderedModel, StatusModel, UserModel

from .. import managers
from .abstracts import AbstractOrganization


class OrganizationAddress(
    Address, AddressCoordinate,
    CleanModel, UserModel, DateModel, StatusModel, OrderedModel
):
    organization = models.ForeignKey(
        swapper.get_model_name('organization', 'Organization'),
        db_index=True,
        on_delete=models.PROTECT,
        related_name='addresses',
        verbose_name=_("organization"),
    )
    org_name = models.CharField(
        max_length=255,
        blank=True,
        db_index=True,
        verbose_name=_("organization name"),
    )
    note = models.TextField(
        blank=True, null=True,
        verbose_name=_("note"),
    )
    geocoding_fields = ['lat', 'lng']

    class Meta:
        verbose_name = _('organization address')
        verbose_name_plural = _('organization addresses')
        ordering = ('ordering', 'org_name',)
        permissions = (
            ("list_organizationaddress", "Can list organization address"),
            ("detail_organizationaddress", "Can detail organization address"),
            ("enable_organizationaddress", "Can enable organization address"),
            ("disable_organizationaddress", "Can disable organization address"),
        )

    def __str__(self):
        return (
            "{organization} {org_name} - {address_type} {name} {number} - {locality} ({province}) - {country}".format(
                organization=self.organization,
                org_name=self.org_name,
                address_type=self.get_address_type_display(),
                name=self.name,
                number=self.number or '',
                locality=self.locality,
                province=self.province,
                country=self.country
            )
        )

    @property
    def organization_name(self):
        return self.organization.name

    @property
    def country_name(self):
        return self.country.name


class EmailTypology(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_('code'),
    )
    name = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        max_length=255,
        unique=True,
        verbose_name=_('slug'),
    )

    class Meta:
        verbose_name = _('email typology')
        verbose_name_plural = _('email typologies')
        ordering = ('ordering', 'name',)
        permissions = (
            ("list_emailtypology", "Can list email typology"),
            ("detail_emailtypology", "Can detail email typology"),
            ("enable_emailtypology", "Can enable email typology"),
            ("disable_emailtypology", "Can disable email typology"),
        )

    def __str__(self):
        return self.name


class PhoneTypology(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_('code'),
    )
    name = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        max_length=255,
        unique=True,
        verbose_name=_('slug'),
    )

    class Meta:
        verbose_name = _('phone typology')
        verbose_name_plural = _('phone typologies')
        ordering = ('ordering', 'name',)
        permissions = (
            ("list_phonetypology", "Can list phone typology"),
            ("detail_phonetypology", "Can detail phone typology"),
            ("enable_phonetypology", "Can enable phone typology"),
            ("disable_phonetypology", "Can disable phone typology"),
        )

    def __str__(self):
        return self.name


class OrganizationType(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        max_length=50,
        verbose_name=_("code"),
    )
    category = models.CharField(
        max_length=3,
        choices=settings.ORGANIZATION_ORGANIZATIONTYPE_CATEGORY_CHOICES,
        db_index=True,
        verbose_name=_("category"),
    )
    name = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_("name"),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_("description"),
    )
    note = models.TextField(
        blank=True,
        verbose_name=_("note"),
    )

    class Meta:
        verbose_name = _('organization type')
        verbose_name_plural = _('organization types')
        ordering = ('ordering', 'name')
        permissions = (
            ("list_organizationtype", "Can list organization type"),
            ("detail_organizationtype", "Can detail organization type"),
            ("enable_organizationtype", "Can enable organization type"),
            ("disable_organizationtype", "Can disable organization type"),
        )

    def __str__(self):
        return self.name


class OrganizationForm(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    code = models.CharField(
        max_length=50,
        unique=True,
        verbose_name=_("code"),
    )
    name = models.CharField(
        max_length=255,
        unique=True,
        verbose_name=_("name"),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_("description"),
    )

    class Meta:
        verbose_name = _('organization form')
        verbose_name_plural = _('organization forms')
        ordering = ("ordering", "name")
        permissions = (
            ("list_organizationform", "Can list organization form"),
            ("detail_organizationform", "Can detail organization form"),
            ("disable_organizationform", "Can disable organization form"),
        )

    def __str__(self):
        return self.name


class Organization(AbstractOrganization):
    class Meta:
        verbose_name = _('organization')
        verbose_name_plural = _('organizations')
        ordering = ('ordering', 'name',)
        permissions = (
            ("list_organization", "Can list organization"),
            ("detail_organization", "Can detail organization"),
            ("enable_organization", "Can enable organization"),
            ("disable_organization", "Can disable organization"),
        )
        swappable = swapper.swappable_setting('organization', 'Organization')


if not swapper.is_swapped("organization", "Organization"):
    class OwnerOrganization(Organization):
        objects = managers.OwnerOrganizationManager()

        class Meta:
            proxy = True
            verbose_name = _('owner organization')
            verbose_name_plural = _('owner organizations')
            permissions = (
                ("list_ownerorganization", "Can list owner organization"),
                ("detail_ownerorganization", "Can detail owner organization"),
                ("enable_ownerorganization", "Can enable owner organization"),
                ("disable_ownerorganization", "Can disable owner organization"),
            )


class OrganizationEmail(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    organization = models.ForeignKey(
        swapper.get_model_name('organization', 'Organization'),
        on_delete=models.PROTECT,
        related_name='emails',
        verbose_name=_('organization'),
    )
    typology = models.ForeignKey(
        "EmailTypology",
        on_delete=models.PROTECT,
        related_name='organization_emails',
        verbose_name=_('typology'),
    )
    email = models.EmailField(
        unique=True,
        max_length=255,
        verbose_name=_("email"),
    )
    is_primary = models.BooleanField(
        default=False,
        verbose_name=_('is primary')
    )

    class Meta:
        verbose_name = _('organization email')
        verbose_name_plural = _('organization emails')
        ordering = ('ordering', 'email',)
        permissions = (
            ("list_organizationemail", "Can list organization email"),
            ("detail_organizationemail", "Can detail organization email"),
            ("enable_organizationemail", "Can enable organization email"),
            ("disable_organizationemail", "Can disable organization email"),
        )

    def __str__(self):
        return '{}: {}'.format(self.typology, self.email)

    def save(self, *args, **kwargs):
        if self.is_primary:
            prim_emails = OrganizationEmail.objects.filter(
                organization=self.organization, is_primary=True
            )
            for email in prim_emails:
                email.is_primary = False
                email.save()
        super().save(*args, **kwargs)

    @property
    def organization_name(self):
        return self.organization.name

    @property
    def typology_name(self):
        return self.typology.name


class OrganizationPhone(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    organization = models.ForeignKey(
        swapper.get_model_name('organization', 'Organization'),
        on_delete=models.PROTECT,
        related_name='phones',
        verbose_name=_('organization'),
    )
    typology = models.ForeignKey(
        PhoneTypology,
        on_delete=models.PROTECT,
        related_name='organization_phones',
        verbose_name=_('typology'),
    )
    phone = models.CharField(
        max_length=20,
        unique=True,
        verbose_name=_("phone"),
    )
    is_primary = models.BooleanField(
        default=False,
        verbose_name=_('is primary')
    )

    class Meta:
        verbose_name = _('organization phone')
        verbose_name_plural = _('organization phones')
        permissions = (
            ("list_organizationphone", "Can list organization phone"),
            ("detail_organizationphone", "Can detail organization phone"),
            ("enable_organizationphone", "Can enable organization phone"),
            ("disable_organizationphone", "Can disable organization phone"),
        )

    def __str__(self):
        return '{}: {}'.format(self.typology, self.phone)

    def save(self, *args, **kwargs):
        if self.is_primary:
            prim_phones = OrganizationPhone.objects.filter(
                organization=self.organization, is_primary=True)
            for phone in prim_phones:
                phone.is_primary = False
                phone.save()
        super().save(*args, **kwargs)

    @property
    def organization_name(self):
        return self.organization.name

    @property
    def typology_name(self):
        return self.typology.name


class OrganizationSocialPage(CleanModel, UserModel, DateModel, StatusModel, OrderedModel):
    organization = models.ForeignKey(
        swapper.get_model_name('organization', 'Organization'),
        on_delete=models.PROTECT,
        related_name='social_pages',
        verbose_name=_('organization'),
    )
    social = models.CharField(
        max_length=255,
        choices=settings.ORGANIZATION_ORGANIZATIONSOCIALPAGE_SOCIAL_DEF,
        db_index=True,
        verbose_name=_('social'),
    )
    link = models.URLField(
        unique=True,
        verbose_name=_('page link')
    )

    class Meta:
        verbose_name = _('organization social page')
        verbose_name_plural = _('organization social pages')
        ordering = ('ordering', 'link',)
        permissions = (
            ("list_organizationsocialpage", "Can list organization social page"),
            ("detail_organizationsocialpage", "Can detail organization social page"),
            ("enable_organizationsocialpage", "Can enable organization social page"),
            ("disable_organizationsocialpage", "Can disable organization social page"),
        )

    def __str__(self):
        return self.link

    @property
    def organization_name(self):
        return self.organization.name
